@@ -1,4 +1,3 @@
-from .classification import ClassificationConfig, ClassificationProblem  # noqa: F401
 from .config import (  # noqa: F401
     deep_to_flat,
     dump_config,
@@ -9,10 +8,27 @@ from .config import (  # noqa: F401
 )
 from .datasets import TFDSConfig, TFDSWrapper  # noqa: F401
 from .interface import ProblemBase  # noqa: F401
-from .model import ModelConfig, ModelFactory  # noqa: F401
+from .model import (  # noqa: F401
+    EmbeddingModelConfig,
+    EmbeddingModelFactory,
+    ModelConfig,
+    ModelFactory,
+    SavedModel,
+    SavedModelConfig,
+)
 from .optimizer import OptimizerConfig, OptimizerFactory  # noqa: F401
+from .problems import (  # noqa: F401
+    ClassificationConfig,
+    ClassificationProblem,
+    DistillationConfig,
+    DistillationProblem,
+)
 from .registry import cfg_serializable, get_cfg_class, get_class  # noqa: F401
 from .timekeeping import Timekeeping  # noqa: F401
 from .train import ExperimentConfig, run  # noqa: F401
 from .trainer import SingleGPUTrainer, TrainerConfig  # noqa: F401
-from .utils import setup_logging  # noqa: F401
+from .utils import (  # noqa: F401
+    collect_files_with_suffix,
+    collect_tfrecord_files,
+    setup_logging,
+)
